@@ -6,7 +6,6 @@ package LinkedList::Single;
 
 use v5.8;
 use strict;
-use FindBin::libs;
 
 use Carp;
 
@@ -74,7 +73,7 @@ use overload
 # package variables
 ########################################################################
 
-our $VERSION    = '0.99.7';
+our $VERSION    = '0.99.9';
 
 # inside-out data for the heads of the lists.
 
@@ -331,16 +330,18 @@ sub is_empty
     ! @{ $$listh }
 }
 
-sub node_data
+sub data
 {
     my $listh   = shift;
     my $node    = $$listh;
 
     # return the existing data, sans the next ref.
 
+    my @valz    = @{ $node }[ 1 .. $#$node ];
+
     wantarray
-    ?   @{ $node }[ 1 .. $#$node ]
-    : [ @{ $node }[ 1 .. $#$node ] ]
+    ?  @valz
+    : \@valz
 }
 
 sub next_data
@@ -394,24 +395,6 @@ sub clear_data
     $listh
 }
 
-sub list_data
-{
-    my $listh   = shift;
-    my $node    = $$listh;
-
-    my @return  = ();
-
-    while( @$node )
-    {
-        my ( $node, @data ) = @$node;
-        push @return, \@data;
-    }
-
-    wantarray
-    ?  @return
-    : \@return
-}
-
 ########################################################################
 # access the list head.
 #
@@ -537,7 +520,8 @@ sub cut
 
     if( defined wantarray )
     {
-        ( $node->[0], my @valz ) = @{ $node->[0] };
+        my @valz   =  @{ $node->[0] };
+        $node->[0] = shift @valz;
 
         wantarray
         ?  @valz
@@ -559,70 +543,57 @@ sub cut
 sub splice
 {
     my $listh   = shift;
-    my $count   = shift || 0;
+    my $count   = shift || 1;
 
     looks_like_number $count
-    or croak "Bogus splice: non-numeric count '$count'";
+    or croak "Bogus splice: non-numeric '$count'";
 
-    $count < 0
-    and croak "Bogus splice: negative count '$count'";
-
-    # short circut if there is nothing to do.
-
-    $count > 0 || @_ or return;
+    $count > 0
+    or croak "Bogus splice: negative count '$count'";
 
     my $node    = $$listh
     or confess "Bogus splice: empty list handler";
 
-    my $dead    = '';
+    my $tail    = $node;
 
-    if( $count > 0 )
+    for( 1 .. $count )
     {
-        my $tail    = $node;
+        @$tail or last;
 
-        for( 1 .. $count )
-        {
-            @$tail or last;
-
-            $tail   = $tail->[0];
-        }
-
-        # this is the start of the chain that gets removed.
-        # keep it alive for a few steps to see if the caller
-        # wants it back or we should clean it up.
-        #
-        # after that, splice the node out of the list.
-
-        $dead       = $node->[0];
-        $node->[0]  = delete $tail->[0];
-        $tail->[0]  = [];
+        $tail   = $tail->[0];
     }
 
-    # at this point $dead is either false or 
-    # a runt linked list lacking its terminating
-    # node.
+    # this is the start of the chain that gets removed.
+    # keep it alive for a few steps to see if the caller
+    # wants it back or we should clean it up.
+    #
+    # after that, splice the node out of the list.
+
+    my $dead    = $node->[0];
+    $node->[0]  = delete $tail->[0];
+
+    # at this point $dead is a runt linked
+    # list without a terminating node.
     #
     # insert anything on the stack after the
     # current node.
 
     for( @_ )
     {
-       $node    = $node->[0] = [ $node->[0], $_ ];
+       $node    = $node->[0] = [ $node->[0], shift ];
     }
 
-    # nothing to return or clean up if there 
-    # wasn't anything removed.
-
-    $dead or return;
-
     # if the caller wants anything back then
     # clean up the dead chain and hand it back.
     #
-    # alternative: array of data?
+    # node: maybe this should return an array of
+    # arrayrefs?
 
     if( defined wantarray )
     {
         # hand back a linked list with $dead as the head node.
+
+        $tail->[0]  = [];
         
         my $new     = $listh->new;
 
@@ -630,16 +601,15 @@ sub splice
 
         @$head      = @$dead;
 
-        return $new
+        $new
     }
     else
     {
-        $cleanup->( $dead );
+        # discard the dead links.
 
-        return
+        $cleanup->( $dead );
     }
 }
-
 ########################################################################
 # aside: push can be very expensive.
 # but, then, so is maintaining a separate
@@ -742,7 +712,7 @@ LinkedList::Single - singly linked list manager.
 
     # extract the data from the current node.
 
-    my @data    = $listh->node_data;
+    my @data    = $listh->data;
 
     # save and restore a node position
 
@@ -824,7 +794,7 @@ LinkedList::Single - singly linked list manager.
 
         my $altlist = $listh->clone;
 
-        my @data    = $altlist->next->node_data;
+        my @data    = $altlist->next->data;
 
         ...
     }
@@ -872,7 +842,7 @@ LinkedList::Single - singly linked list manager.
         # deal with @data
     }
 
-    # note that $listh->next->node_data may be empty
+    # note that $listh->next->data may be empty
     # even if there are mode nodes due to a node
     # having no data.
 
@@ -978,7 +948,7 @@ into a single method because there isn't any clean way
 to determine if the node needs to be emptied or left
 unmodified due to an empty stack. The option of using
 
-    $listh->node_data( undef )
+    $listh->data( undef )
 
 for cleaning the node leaves no way to store an explicit
 undef in the node.
